(require '[clojure.string :as string])
(require '[clojure.java.io :refer [file]])
(require '[clojure.java.shell :refer [sh]])

(def tk-version "1.0.0")
(def ks-version "1.0.0")
(def rbac-svc-version "0.3.1")
(def activity-svc-version "0.1.11")

(defn deploy-info
  [url]
  {:url url
   :username :env/nexus_jenkins_username
   :password :env/nexus_jenkins_password
   :sign-releases false})

(defproject puppetlabs/classifier "1.3.2"
  :description "Node classifier"
  :dependencies [[org.clojure/clojure "1.6.0"]
                 [org.clojure/tools.logging "0.2.6"]
                 [org.clojure/java.jdbc "0.3.2"]
                 [com.jolbox/bonecp "0.8.0.RELEASE" :exclusions [org.slf4j/slf4j-api]]
                 [cheshire "5.3.1"]
                 [clj-stacktrace "0.2.7"]
                 [clj-time "0.6.0"]
                 [compojure "1.1.6" :exclusions [[clj-time] [org.clojure/tools.macro]]]
                 [fast-zip-visit "1.0.2"]
                 [java-jdbc/dsl "0.1.0"]
                 [liberator "0.11.0"]
                 [migratus "0.7.0"]
                 [overtone/at-at "1.2.0"]
                 [org.postgresql/postgresql "9.3-1100-jdbc41"]
                 [prismatic/schema "0.2.2"]
                 [slingshot "0.10.3"]
                 [com.taoensso/tower "3.0.2" :exclusions [org.clojure/tools.reader]]
                 [puppetlabs/http-client "0.4.0" :exclusions [commons-io]]
                 [puppetlabs/certificate-authority "0.6.0"]
                 [puppetlabs/kitchensink ~ks-version]
                 [puppetlabs/liberator-util "0.2.1" :exclusions [liberator]]
                 [puppetlabs/ring-middleware "0.2.0" :exclusions [ring/ring-servlet ring/ring-core hiccup org.clojure/java.classpath]]
                 [puppetlabs/schema-tools "0.1.0" :exclusions [prismatic/schema]]
                 [puppetlabs/trapperkeeper ~tk-version]]
  :profiles {:dev {:dependencies [[clj-http "0.7.9" :exclusions [org.apache.httpcomponents/httpclient]]
                                  [me.raynes/conch "0.5.0" :exclusions [org.clojure/tools.macro]]
                                  [com.github.jnr/jffi "1.2.7"]
                                  [com.github.jnr/jffi "1.2.7" :classifier "native"]
                                  [com.github.jnr/jnr-x86asm "1.0.2"]
                                  [puppetlabs/puppet-server "2.0.0-SNAPSHOT"]
                                  [ring-mock "0.1.5"]
                                  [spyscope "0.1.3" :exclusions [[clj-time]]]
                                  [puppetlabs/kitchensink ~ks-version :classifier "test"]
                                  [puppetlabs/pe-activity-service ~activity-svc-version]
                                  [puppetlabs/pe-rbac-service ~rbac-svc-version]
                                  [puppetlabs/pe-rbac-service ~rbac-svc-version :classifier "test"]
                                  [puppetlabs/pe-trapperkeeper-ldap-apacheds "0.2.9"
                                   :exclusions [bouncycastle/bcprov-jdk15 org.slf4j/slf4j-log4j12]]
                                  [puppetlabs/trapperkeeper ~tk-version :classifier "test"]
                                  [puppetlabs/trapperkeeper-webserver-jetty9 "1.1.0"]]
                   :injections [(require 'spyscope.core)]
                   :jvm-opts ["-Xss4096k"]}
             :bench {:dependencies [[criterium "0.4.3"]]
                     :jvm-opts ["-Xmx1024m" "-Xms1024m"]
                     :source-paths ["src"]
                     :test-paths ["test" "dev-resources/benchmarks"]}
             :ci {:plugins [[lein-pprint "1.1.1"]]}}
  :classifiers {:test {:source-paths ^:replace ["test"]
                       :resource-paths ^:replace ["dev-resources"]}}
  :repositories [["releases" "http://nexus.delivery.puppetlabs.net/content/repositories/releases/"]
                 ["snapshots" "http://nexus.delivery.puppetlabs.net/content/repositories/snapshots/"]]
  :test-selectors {:default (complement :database)
                   :database :database
                   :acceptance :acceptance
                   :all (constantly true)}
  :aliases {"initdb" ["run" "--bootstrap-config" "resources/puppetlabs/classifier/initdb.cfg"]
            "bench" ["with-profile" "+bench" "test" "puppetlabs.classifier.benchmark"]}
  :uberjar-name "classifier.jar"
  :main ^:skip-aot puppetlabs.trapperkeeper.main
  ;; For release
  :plugins [[lein-release "1.0.5"]]
  :jar-exclusions [#"\.sw[a-z]$" #"~$" #"logback\.xml$" #"log4j\.properties$"]
  :lein-release {:scm :git, :deploy-via :lein-deploy}
  :deploy-repositories [["releases" ~(deploy-info "http://nexus.delivery.puppetlabs.net/content/repositories/releases/")]
                        ["snapshots" ~(deploy-info "http://nexus.delivery.puppetlabs.net/content/repositories/snapshots/")]]
  ;; Put our puppet plugin code in the jar because that's where packaging
  ;; expects it
  :resource-paths ["resources" "puppet/lib" "resources/puppetlabs/classifier" "resources/ext/docs"])
